# DEPRECATED Python Protobuf implementation for Furya

Furya Proto python library will not be maintained any further by TFL officialy. 

Alternative options to this library can be found here:
- GoLang [Furya Core](https://github.com/furya-money/core) clients, 
- JavaScript [@fanfury/furya.proto](https://www.npmjs.com/package/@fanfury/furya.proto/),
- Rust [furya-proto-rs](https://crates.io/crates/furya-proto-rs).